# The base of the version (just major and minor without point)
%global base_version 2.4

Name:           odb
Version:        %{base_version}.0
Release:        21%{?dist}
Summary:        Object-relational mapping (ORM) system for C++

Group:          Development/Tools
License:        GPLv3
URL:            http://www.codesynthesis.com/products/odb/
Source0:        http://www.codesynthesis.com/download/odb/%{base_version}/%{name}-%{version}.tar.bz2
Patch1:         odb_gcc6.patch
# See http://codesynthesis.com/pipermail/odb-users/2016-December/003581.html
Patch2:         odb_gcc6_fix.patch

# Set BuildRoot for compatibility with EPEL <= 5
# See: http://fedoraproject.org/wiki/EPEL:Packaging#BuildRoot_tag
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

# If building on Fedora or RHEL 7
%if 0%{?rhel}%{?fedora} >= 7
# Then it just needs to be at least gcc 4.5.0 for plugin support
BuildRequires: gcc-c++ >= 4.5.0
BuildRequires: gcc-plugin-devel
%else
# Otherwise, use devtoolset on RHEL 5/6 because it supports plugins
BuildRequires: devtoolset-2-binutils
BuildRequires: devtoolset-2-gcc-c++
BuildRequires: devtoolset-2-gcc-plugin-devel
%endif
# Uses libcutl from Code Synthesis
BuildRequires: libcutl-devel >= 1.8.0
# Uses pkgconfig
BuildRequires: pkgconfig
# Uses expat
BuildRequires: expat-devel


# If building on Fedora or RHEL 7
%if 0%{?rhel}%{?fedora} >= 7
  #Then odb uses the gcc plugin directory
  %global ODB_PLUGIN_DIR %(g++ -print-file-name=plugin)
%else
  # Otherwise, it just uses the system directory
  %global ODB_PLUGIN_DIR %{_libexecdir}/odb/
%endif


%description
ODB is an object-relational mapping (ORM) system for C++. It provides
tools, APIs, and library support that allow you to persist C++ objects
to a relational database (RDBMS) without having to deal with tables,
columns, or SQL and without manually writing any of the mapping code.


%prep
%autosetup -p1
# Set the path to the default.options file
%global odb_default_options_dir %{_sysconfdir}/%{name}
%global odb_default_options_file %{odb_default_options_dir}/default.options


%build
confopts="--disable-static --with-options-file=%{odb_default_options_file}"
# If building on RHEL 5/6
%if 0%{?rhel}%{?fedora} <= 6
# Otherwise, use devtoolset on RHEL 5/6 to get a version of gcc that supports plugins
source /opt/rh/devtoolset-2/enable
# Add the explicit linking of pthread library because of a toolchain issue
# See: http://www.codesynthesis.com/pipermail/odb-users/2013-February/001103.html
confopts="$confopts LIBS=-lpthread"
%endif
%configure $confopts
make %{?_smp_mflags}


%install
rm -rf $RPM_BUILD_ROOT
make install DESTDIR=$RPM_BUILD_ROOT

# Add the .conf file
mkdir -p $RPM_BUILD_ROOT/%{odb_default_options_dir}
echo "# Default ODB options file. This file is automatically loaded by the ODB
# compiler and can be used for installation-wide customizations, such as
# adding an include search path for a commonly used library. For example:
# -I %{_includedir}/boost141
#" > $RPM_BUILD_ROOT/%{odb_default_options_file}


%clean
rm -rf $RPM_BUILD_ROOT


%files
%config(noreplace) %{odb_default_options_file}
%doc GPLv3
%doc LICENSE
%doc NEWS
%doc doc/default.css
%doc doc/manual.xhtml
%doc doc/odb-arch.png
%doc doc/odb-flow.png
%doc doc/odb-manual.pdf
%doc doc/odb-manual.ps
%doc doc/odb.xhtml
%{_bindir}/odb
%{ODB_PLUGIN_DIR}
%{_mandir}/man1/odb.1.gz
# Exclude the documentation that doesn't need to be packaged
%exclude %{_datadir}/doc/odb/GPLv3
%exclude %{_datadir}/doc/odb/LICENSE
%exclude %{_datadir}/doc/odb/NEWS
%exclude %{_datadir}/doc/odb/README
%exclude %{_datadir}/doc/odb/default.css
%exclude %{_datadir}/doc/odb/manual.xhtml
%exclude %{_datadir}/doc/odb/odb-arch.png
%exclude %{_datadir}/doc/odb/odb-flow.png
%exclude %{_datadir}/doc/odb/odb-manual.pdf
%exclude %{_datadir}/doc/odb/odb-manual.ps
%exclude %{_datadir}/doc/odb/odb.xhtml
%exclude %{_datadir}/doc/odb/version


%changelog
* Thu Aug 03 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.4.0-21
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 2.4.0-20
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Sat Feb 25 2017 Dave Johansen <davejohansen@gmail.com> 2.4.0-19
- Rebuild for gcc 7 without requires on specific version

* Sun Feb 05 2017 Kalev Lember <klember@redhat.com> 2.4.0-18
- Rebuild for gcc update

* Sun Jan 01 2017 Dave Johansen <davejohansen@gmail.com> 2.4.0-17
- Rebuild for gcc update

* Fri Dec 23 2016 Dave Johansen <davejohansen@gmail.com> 2.4.0-16
- Fix for gcc 6

* Sat Sep 10 2016 Dave Johansen <davejohansen@gmail.com> 2.4.0-15
- Rebuild for gcc update

* Fri Jul 08 2016 Dave Johansen <davejohansen@gmail.com> 2.4.0-14
- Rebuild for gcc update (see Bugzilla #1350948)

* Sun May 15 2016 Dave Johansen <davejohansen@gmail.com> 2.4.0-13
- Rebuild for gcc update

* Fri Apr 29 2016 Dave Johansen <davejohansen@gmail.com> 2.4.0-12
- Rebuild for gcc update

* Sat Feb 06 2016 Dave Johansen <davejohansen@gmail.com> 2.4.0-11
- Patch for gcc 6

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 2.4.0-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Fri Jan 29 2016 Dave Johansen <davejohansen@gmail.com> 2.4.0-9
- Rebuild for gcc update

* Fri Dec 11 2015 Dave Johansen <davejohansen@gmail.com> 2.4.0-8
- Rebuild for gcc update

* Tue Nov 24 2015 Dave Johansen <davejohansen@gmail.com> 2.4.0-7
- Rebuild for libcutl 1.10.0

* Fri Nov 06 2015 Dave Johansen <davejohansen@gmail.com> 2.4.0-6
- Rebuild for gcc update

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.4.0-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Fri Apr 24 2015 Dave Johansen <davejohansen@gmail.com> 2.4.0-4
- Rebuild for gcc update

* Thu Apr 16 2015 Dave Johansen <davejohansen@gmail.com> 2.4.0-3
- Rebuild for gcc update

* Mon Feb 16 2015 Dave Johansen <davejohansen@gmail.com> 2.4.0-2
- Rebuild for gcc 5.0 C++ ABI change

* Wed Feb 11 2015 Dave Johansen <davejohansen@gmail.com> 2.4.0-1
- Updated to 2.4.0

* Fri Feb 06 2015 Dave Johansen <davejohansen@gmail.com> - 2.3.0-9
- Rebuilt for gcc 5.0.0

* Wed Nov 05 2014 Dave Johansen <davejohansen@gmail.com> - 2.3.0-8
- Rebuilt for gcc 4.9.2

* Sun Aug 17 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.3.0-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_22_Mass_Rebuild

* Fri Jul 18 2014 Dave Johansen <davejohansen@gmail.com> 2.3.0-6
- Require the version of GCC that its being built against

* Sun Jul  6 2014 Ville Skyttä <ville.skytta@iki.fi> - 2.3.0-5
- Build with $RPM_OPT_FLAGS

* Wed Jun 11 2014 Dave Johansen <davejohansen@gmail.com> 2.3.0-4
- Patch to build with gcc 4.9

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2.3.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild
- Build against devtoolset 2.0

* Wed May 28 2014 Dave Johansen <davejohansen@gmail.com> 2.3.0-2
- Adding expat-devel as BuildRequires

* Mon Nov 4 2013 Dave Johansen <davejohansen@gmail.com> 2.3.0-1
- Updated to 2.3.0

* Tue Jul 23 2013 Dave Johansen <davejohansen@gmail.com> 2.2.2-1
- Initial build
